# CE common UI

This project holds common React hooks and components for CE UI applications.

## Developing environment

- NodeJS and npm
- IDE for JavaScript developement (e.g. Visual Studio Code)
- Credentials from ESS Artifactory, with permission to the ics-npm registry

(For developing purposes it is suggested to use _Node Version Manager_ [NVM] which makes easy to change between different Node versions).

- Windows: https://github.com/coreybutler/nvm-windows
- Mac/Linux: https://github.com/nvm-sh/nvm

### Required versions

- Node: v20+
- npm: v6.10+

## Local development setup

### Installing Dependencies

This project includes private dependencies from Artifactory, so additional configuration is required.

1.  Create an `.npmrc` file based on the example provided in this registry, substituting your email and base64 credentials.
1.  Install dependencies with `npm ci`.

Note, we lock dependency versions with _package-lock.json_; please install dependencies with `npm ci` (not npm install) to avoid overwriting the package-lock.

### Setting Environment Variables

Environment variables are stored in `.env` files.
Precedency of environment variable files are (files on the left have more priority than files on the right):

- npm run ci:build: `.env.production.local`, `.env.local`, `.env.production`, `.env`

All environment variables start with `VITE_` prefix.

## Available Scripts

In the project directory, you can run:

## [ESLint](https://eslint.org) & [Prettier](https://prettier.io)

Linting can be checked, and to some extent auto fixed by running following scripts:

```bash
npm run lint
```

will run `npx eslint src` which will run eslint on all files in the src directory and write out the results of the check in your console.

```bash
npm run lint:fix
```

will run `npm run lint -- --fix` which will run eslint on all files in the src directory and fix what can be auto fixed and write out the rest of the results of the check, of what could not be auto fixed, in your console.

```bash
npm run prettier
```

will run `npx prettier src --check` which will run prettier on all files in the src directory and write out which files would be changed in your console.

```bash
npm run prettier:fix
```

```bash
npm run cypress:open
```

will run `npm run prettier -- --write` which will run prettier on all files in the src directory and write out which files have be changed in your console.

## [Pre-Commit](https://pre-commit.com/)

### Pre-commit

You will need to install pre-commit first locally on you machine, the install it in you project, instructions on how to do this you can find here: https://pre-commit.com/#install

By running `pre-commit run --all-files` pre-commit will run both eslint and prettier on all files in src, much like the scripts from the package.json

## Building

```bash
npm run ci:build
```

Builds the app for production to the `build` folder.\
It correctly bundles React in production mode and optimizes the build for the best performance.

The build is minified and the filenames include the hashes.\
Your app is ready to be deployed!

See the section about [deployment](https://vite.dev/guide/static-deploy.html) for more information.

# Testing changes against other CE UI repos

In order to test your changes against any of our repos you have to do the following:

1. Create a merge-request
2. Once the pipefile finishes, find the action deploy-package-devel (it's under deploy step) and run it
3. In the build logs look for the "npm notice version", looks something like "9.0.0-27617eb1"
4. Install this version in any of the repos you want to test your changes

## Learn More

You can learn more in the [vite documentation](https://vite.dev/guide/).

To learn React, check out the [React documentation](https://reactjs.org/).
